netapp_ontap.models.rotation API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.rotation`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class RotationSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the Rotation object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `now PATCH`

    Manually rotates the audit logs. Optional in PATCH only. Not available in POST.

  `schedule GET POST PATCH`

    The schedule field of the rotation.

  `size GET POST PATCH`

    Rotates logs based on log size in bytes.